# coding: utf-8

"""
    Red Rover API

    Access Red Rover data via this REST API for Organizations that have granted you access.    # Authentication  The API is protected by HTTP Basic Authentication.   Each application that connects to the API has a unique username and password that it must supply with every request.    This value needs to be supplied as an HTTP Header: `Authorization=BASIC [hash]`. The value of [hash] is the string username:password base64 encoded.    Endpoints marked for Basic Auth can be used with the Basic Auth username and password that you have been assigned.    # API Information  ## Api Key  Each Red Rover organization that has authorized your application has a unique API Key for your application.  To retrieve the API Key, you can use the Organization endpoint (`api/v1/organization`) which returns an ApiKey uniquely used for each Organization.    You must supply this as an HTTP Header when accessing that organization: `apiKey=[apiKey]`. The domains that require this `ApiKey` header are labeled as 'Requires an ApiKey'.    ## Identifier  Where an `Identifier` can be specified in the route, you may either supply the Red Rover Id of the object (numeric) or the External Id (alpha-numeric). When specifying an External Id, you will need to prepend the External Id with the pipe character`|` (e.g. `|ABC123`). Please note that this is only the case when the External Id is within the route. If the External Id is contained within the body of the request, do not append the pipe character.    ## Rate Limiting  Requests are rate limited at a default rate of 100 requests per minute    ## Transaction Id  Each request can be supplied with a `TransactionId` GUID which will be logged with the request. The `Transaction Id` can be supplied as an HTTP Header: `TransactionId=[transactionId]`. If no `Transaction Id` is supplied, one will be generated for you. Please use a distinct TransactionId for each request.

    The version of the OpenAPI document: v1
    Contact: dev@redroverk12.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional, Union
from pydantic import BaseModel, StrictBool, StrictFloat, StrictInt, StrictStr
from pydantic import Field
from redrover_api.models.int32_id_name_class import Int32IdNameClass
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class LocationResponse(BaseModel):
    """
    The details of a location belonging to an organization
    """ # noqa: E501
    location_group: Optional[Int32IdNameClass] = Field(default=None, alias="locationGroup")
    notes: Optional[StrictStr] = Field(default=None, description="Notes about the location.")
    code: Optional[StrictStr] = Field(default=None, description="The location's code")
    available_to_hiring: Optional[StrictBool] = Field(default=None, description="Indicates if the location is available for hiring. If false, the location will not be available for hiring.", alias="availableToHiring")
    phone_number: Optional[StrictStr] = Field(default=None, description="The phone number associated with the location", alias="phoneNumber")
    time_zone: Optional[StrictInt] = Field(default=None, alias="timeZone")
    valid_until_utc: Optional[datetime] = Field(default=None, description="The expiration date of the location", alias="validUntilUtc")
    address1: Optional[StrictStr] = Field(default=None, description="The location's address")
    address2: Optional[StrictStr] = Field(default=None, description="The location's address (continued)")
    city: Optional[StrictStr] = Field(default=None, description="The city of the location")
    state: Optional[StrictInt] = None
    postal_code: Optional[StrictStr] = Field(default=None, description="The postal code of the location", alias="postalCode")
    country: Optional[StrictInt] = None
    longitude: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The longitude of the location")
    latitude: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The latitude of the location")
    name: Optional[StrictStr] = None
    id: Optional[StrictInt] = None
    external_id: Optional[StrictStr] = Field(default=None, alias="externalId")
    __properties: ClassVar[List[str]] = ["locationGroup", "notes", "code", "availableToHiring", "phoneNumber", "timeZone", "validUntilUtc", "address1", "address2", "city", "state", "postalCode", "country", "longitude", "latitude", "name", "id", "externalId"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LocationResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of location_group
        if self.location_group:
            _dict['locationGroup'] = self.location_group.to_dict()
        # set to None if notes (nullable) is None
        # and model_fields_set contains the field
        if self.notes is None and "notes" in self.model_fields_set:
            _dict['notes'] = None

        # set to None if code (nullable) is None
        # and model_fields_set contains the field
        if self.code is None and "code" in self.model_fields_set:
            _dict['code'] = None

        # set to None if phone_number (nullable) is None
        # and model_fields_set contains the field
        if self.phone_number is None and "phone_number" in self.model_fields_set:
            _dict['phoneNumber'] = None

        # set to None if address1 (nullable) is None
        # and model_fields_set contains the field
        if self.address1 is None and "address1" in self.model_fields_set:
            _dict['address1'] = None

        # set to None if address2 (nullable) is None
        # and model_fields_set contains the field
        if self.address2 is None and "address2" in self.model_fields_set:
            _dict['address2'] = None

        # set to None if city (nullable) is None
        # and model_fields_set contains the field
        if self.city is None and "city" in self.model_fields_set:
            _dict['city'] = None

        # set to None if postal_code (nullable) is None
        # and model_fields_set contains the field
        if self.postal_code is None and "postal_code" in self.model_fields_set:
            _dict['postalCode'] = None

        # set to None if longitude (nullable) is None
        # and model_fields_set contains the field
        if self.longitude is None and "longitude" in self.model_fields_set:
            _dict['longitude'] = None

        # set to None if latitude (nullable) is None
        # and model_fields_set contains the field
        if self.latitude is None and "latitude" in self.model_fields_set:
            _dict['latitude'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if external_id (nullable) is None
        # and model_fields_set contains the field
        if self.external_id is None and "external_id" in self.model_fields_set:
            _dict['externalId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of LocationResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "locationGroup": Int32IdNameClass.from_dict(obj.get("locationGroup")) if obj.get("locationGroup") is not None else None,
            "notes": obj.get("notes"),
            "code": obj.get("code"),
            "availableToHiring": obj.get("availableToHiring"),
            "phoneNumber": obj.get("phoneNumber"),
            "timeZone": obj.get("timeZone"),
            "validUntilUtc": obj.get("validUntilUtc"),
            "address1": obj.get("address1"),
            "address2": obj.get("address2"),
            "city": obj.get("city"),
            "state": obj.get("state"),
            "postalCode": obj.get("postalCode"),
            "country": obj.get("country"),
            "longitude": obj.get("longitude"),
            "latitude": obj.get("latitude"),
            "name": obj.get("name"),
            "id": obj.get("id"),
            "externalId": obj.get("externalId")
        })
        return _obj


