# coding: utf-8

"""
    Red Rover API

    Access Red Rover data via this REST API for Organizations that have granted you access.    # Authentication  The API is protected by HTTP Basic Authentication.   Each application that connects to the API has a unique username and password that it must supply with every request.    This value needs to be supplied as an HTTP Header: `Authorization=BASIC [hash]`. The value of [hash] is the string username:password base64 encoded.    Endpoints marked for Basic Auth can be used with the Basic Auth username and password that you have been assigned.    # API Information  ## Api Key  Each Red Rover organization that has authorized your application has a unique API Key for your application.  To retrieve the API Key, you can use the Organization endpoint (`api/v1/organization`) which returns an ApiKey uniquely used for each Organization.    You must supply this as an HTTP Header when accessing that organization: `apiKey=[apiKey]`. The domains that require this `ApiKey` header are labeled as 'Requires an ApiKey'.    ## Identifier  Where an `Identifier` can be specified in the route, you may either supply the Red Rover Id of the object (numeric) or the External Id (alpha-numeric). When specifying an External Id, you will need to prepend the External Id with the pipe character`|` (e.g. `|ABC123`). Please note that this is only the case when the External Id is within the route. If the External Id is contained within the body of the request, do not append the pipe character.    ## Rate Limiting  Requests are rate limited at a default rate of 100 requests per minute    ## Transaction Id  Each request can be supplied with a `TransactionId` GUID which will be logged with the request. The `Transaction Id` can be supplied as an HTTP Header: `TransactionId=[transactionId]`. If no `Transaction Id` is supplied, one will be generated for you. Please use a distinct TransactionId for each request.

    The version of the OpenAPI document: v1
    Contact: dev@redroverk12.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional, Union
from pydantic import BaseModel, StrictBool, StrictFloat, StrictInt
from pydantic import Field
from typing_extensions import Annotated
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class PayCodeUpdateRequest(BaseModel):
    """
    PayCodeUpdateRequest
    """ # noqa: E501
    name: Annotated[str, Field(min_length=1, strict=True)] = Field(description="The name of the pay code")
    description: Annotated[str, Field(min_length=1, strict=True)] = Field(description="The pay code's description")
    external_id: Annotated[str, Field(min_length=1, strict=True)] = Field(description="The pay code's ExternalId", alias="externalId")
    expired: StrictBool = Field(description="If the pay code is expired")
    code: Annotated[str, Field(min_length=1, strict=True, max_length=50)] = Field(description="The assigned code of the code")
    hourly_rate: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The hourly rate", alias="hourlyRate")
    unit_rate: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The unit rate", alias="unitRate")
    half_day_rate: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The half date rate", alias="halfDayRate")
    full_day_rate: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The full date rate", alias="fullDayRate")
    __properties: ClassVar[List[str]] = ["name", "description", "externalId", "expired", "code", "hourlyRate", "unitRate", "halfDayRate", "fullDayRate"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of PayCodeUpdateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # set to None if hourly_rate (nullable) is None
        # and model_fields_set contains the field
        if self.hourly_rate is None and "hourly_rate" in self.model_fields_set:
            _dict['hourlyRate'] = None

        # set to None if unit_rate (nullable) is None
        # and model_fields_set contains the field
        if self.unit_rate is None and "unit_rate" in self.model_fields_set:
            _dict['unitRate'] = None

        # set to None if half_day_rate (nullable) is None
        # and model_fields_set contains the field
        if self.half_day_rate is None and "half_day_rate" in self.model_fields_set:
            _dict['halfDayRate'] = None

        # set to None if full_day_rate (nullable) is None
        # and model_fields_set contains the field
        if self.full_day_rate is None and "full_day_rate" in self.model_fields_set:
            _dict['fullDayRate'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of PayCodeUpdateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "externalId": obj.get("externalId"),
            "expired": obj.get("expired"),
            "code": obj.get("code"),
            "hourlyRate": obj.get("hourlyRate"),
            "unitRate": obj.get("unitRate"),
            "halfDayRate": obj.get("halfDayRate"),
            "fullDayRate": obj.get("fullDayRate")
        })
        return _obj


