# coding: utf-8

"""
    Red Rover API

    Access Red Rover data via this REST API for Organizations that have granted you access.    # Authentication  The API is protected by HTTP Basic Authentication.   Each application that connects to the API has a unique username and password that it must supply with every request.    This value needs to be supplied as an HTTP Header: `Authorization=BASIC [hash]`. The value of [hash] is the string username:password base64 encoded.    Endpoints marked for Basic Auth can be used with the Basic Auth username and password that you have been assigned.    # API Information  ## Api Key  Each Red Rover organization that has authorized your application has a unique API Key for your application.  To retrieve the API Key, you can use the Organization endpoint (`api/v1/organization`) which returns an ApiKey uniquely used for each Organization.    You must supply this as an HTTP Header when accessing that organization: `apiKey=[apiKey]`. The domains that require this `ApiKey` header are labeled as 'Requires an ApiKey'.    ## Identifier  Where an `Identifier` can be specified in the route, you may either supply the Red Rover Id of the object (numeric) or the External Id (alpha-numeric). When specifying an External Id, you will need to prepend the External Id with the pipe character`|` (e.g. `|ABC123`). Please note that this is only the case when the External Id is within the route. If the External Id is contained within the body of the request, do not append the pipe character.    ## Rate Limiting  Requests are rate limited at a default rate of 100 requests per minute    ## Transaction Id  Each request can be supplied with a `TransactionId` GUID which will be logged with the request. The `Transaction Id` can be supplied as an HTTP Header: `TransactionId=[transactionId]`. If no `Transaction Id` is supplied, one will be generated for you. Please use a distinct TransactionId for each request.

    The version of the OpenAPI document: v1
    Contact: dev@redroverk12.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional, Union
from pydantic import BaseModel, StrictBool, StrictFloat, StrictInt, StrictStr
from pydantic import Field
from redrover_api.models.accounting_code_allocation_request import AccountingCodeAllocationRequest
from redrover_api.models.int32_locator_request import Int32LocatorRequest
from redrover_api.models.position_job_request import PositionJobRequest
from redrover_api.models.position_schedule_mode_enum import PositionScheduleModeEnum
from redrover_api.models.position_schedule_request import PositionScheduleRequest
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class PositionRequest(BaseModel):
    """
    The Identifiers of the object
    """ # noqa: E501
    name: Optional[StrictStr] = Field(default=None, description="The Position's name")
    position_schedule_mode_id: Optional[PositionScheduleModeEnum] = Field(default=None, alias="positionScheduleModeId")
    contract: Int32LocatorRequest
    position_type: Int32LocatorRequest = Field(alias="positionType")
    hours_per_full_work_day: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Amount of hours per a full workday (hours)", alias="hoursPerFullWorkDay")
    needs_replacement: Optional[StrictInt] = Field(default=None, alias="needsReplacement")
    start_date: Optional[datetime] = Field(default=None, description="The StartDate of the Position", alias="startDate")
    end_date: Optional[datetime] = Field(default=None, description="The EndDate of the Position", alias="endDate")
    is_staff_augmentation: Optional[StrictBool] = Field(default=None, description="Is the Position for staff augmentation", alias="isStaffAugmentation")
    fte: Optional[Union[StrictFloat, StrictInt]] = None
    qualified_for_pto: Optional[StrictBool] = Field(default=None, description="Is the Position qualified for paid time off", alias="qualifiedForPto")
    qualified_for_paid_holidays: Optional[StrictBool] = Field(default=None, description="Is the Position qualified for holidays", alias="qualifiedForPaidHolidays")
    qualified_for_pto_as_of: Optional[datetime] = Field(default=None, description="The effective date that the Position qualifies for paid time off (If not included, the default is that it is always qualified)", alias="qualifiedForPtoAsOf")
    qualified_for_paid_holidays_as_of: Optional[datetime] = Field(default=None, description="The effective date that the Position qualifies for holidays (If not included, the default is that it is always qualified)", alias="qualifiedForPaidHolidaysAsOf")
    default_job_pay_override: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="defaultJobPayOverride")
    code: Optional[StrictStr] = Field(default=None, description="The 'Code' for the Position.")
    schedules: Optional[List[PositionScheduleRequest]] = Field(default=None, description="The Schedules for the Position. If PositionScheduleModeId is 'Flexible - No Schedule' this should be omitted or an empty list.")
    replace_existing_position_jobs: Optional[StrictBool] = Field(default=None, description="If existing Position Jobs are to be replaced. (Default is true)", alias="replaceExistingPositionJobs")
    allowed_location_ids: Optional[List[Int32LocatorRequest]] = Field(default=None, description="Locations the Position is granted. (If the position is unscheduled)", alias="allowedLocationIds")
    other_jobs: Optional[List[PositionJobRequest]] = Field(default=None, description="Other Jobs", alias="otherJobs")
    primary_job: Optional[PositionJobRequest] = Field(default=None, alias="primaryJob")
    supervisor: Optional[Int32LocatorRequest] = None
    fallback_supervisors: Optional[List[Int32LocatorRequest]] = Field(default=None, description="A list of fallback supervisors for this position", alias="fallbackSupervisors")
    accounting_code_allocations: Optional[List[AccountingCodeAllocationRequest]] = Field(default=None, description="The Accounting Code Allocation for this position", alias="accountingCodeAllocations")
    id: Optional[StrictInt] = Field(default=None, description="The Red Rover Id (numeric)")
    external_id: Optional[StrictStr] = Field(default=None, description="The External Id (alpha-numeric)", alias="externalId")
    __properties: ClassVar[List[str]] = ["name", "positionScheduleModeId", "contract", "positionType", "hoursPerFullWorkDay", "needsReplacement", "startDate", "endDate", "isStaffAugmentation", "fte", "qualifiedForPto", "qualifiedForPaidHolidays", "qualifiedForPtoAsOf", "qualifiedForPaidHolidaysAsOf", "defaultJobPayOverride", "code", "schedules", "replaceExistingPositionJobs", "allowedLocationIds", "otherJobs", "primaryJob", "supervisor", "fallbackSupervisors", "accountingCodeAllocations", "id", "externalId"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of PositionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
                "is_staff_augmentation",
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of contract
        if self.contract:
            _dict['contract'] = self.contract.to_dict()
        # override the default output from pydantic by calling `to_dict()` of position_type
        if self.position_type:
            _dict['positionType'] = self.position_type.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in schedules (list)
        _items = []
        if self.schedules:
            for _item in self.schedules:
                if _item:
                    _items.append(_item.to_dict())
            _dict['schedules'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in allowed_location_ids (list)
        _items = []
        if self.allowed_location_ids:
            for _item in self.allowed_location_ids:
                if _item:
                    _items.append(_item.to_dict())
            _dict['allowedLocationIds'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in other_jobs (list)
        _items = []
        if self.other_jobs:
            for _item in self.other_jobs:
                if _item:
                    _items.append(_item.to_dict())
            _dict['otherJobs'] = _items
        # override the default output from pydantic by calling `to_dict()` of primary_job
        if self.primary_job:
            _dict['primaryJob'] = self.primary_job.to_dict()
        # override the default output from pydantic by calling `to_dict()` of supervisor
        if self.supervisor:
            _dict['supervisor'] = self.supervisor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in fallback_supervisors (list)
        _items = []
        if self.fallback_supervisors:
            for _item in self.fallback_supervisors:
                if _item:
                    _items.append(_item.to_dict())
            _dict['fallbackSupervisors'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in accounting_code_allocations (list)
        _items = []
        if self.accounting_code_allocations:
            for _item in self.accounting_code_allocations:
                if _item:
                    _items.append(_item.to_dict())
            _dict['accountingCodeAllocations'] = _items
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if hours_per_full_work_day (nullable) is None
        # and model_fields_set contains the field
        if self.hours_per_full_work_day is None and "hours_per_full_work_day" in self.model_fields_set:
            _dict['hoursPerFullWorkDay'] = None

        # set to None if start_date (nullable) is None
        # and model_fields_set contains the field
        if self.start_date is None and "start_date" in self.model_fields_set:
            _dict['startDate'] = None

        # set to None if end_date (nullable) is None
        # and model_fields_set contains the field
        if self.end_date is None and "end_date" in self.model_fields_set:
            _dict['endDate'] = None

        # set to None if is_staff_augmentation (nullable) is None
        # and model_fields_set contains the field
        if self.is_staff_augmentation is None and "is_staff_augmentation" in self.model_fields_set:
            _dict['isStaffAugmentation'] = None

        # set to None if fte (nullable) is None
        # and model_fields_set contains the field
        if self.fte is None and "fte" in self.model_fields_set:
            _dict['fte'] = None

        # set to None if qualified_for_pto (nullable) is None
        # and model_fields_set contains the field
        if self.qualified_for_pto is None and "qualified_for_pto" in self.model_fields_set:
            _dict['qualifiedForPto'] = None

        # set to None if qualified_for_paid_holidays (nullable) is None
        # and model_fields_set contains the field
        if self.qualified_for_paid_holidays is None and "qualified_for_paid_holidays" in self.model_fields_set:
            _dict['qualifiedForPaidHolidays'] = None

        # set to None if qualified_for_pto_as_of (nullable) is None
        # and model_fields_set contains the field
        if self.qualified_for_pto_as_of is None and "qualified_for_pto_as_of" in self.model_fields_set:
            _dict['qualifiedForPtoAsOf'] = None

        # set to None if qualified_for_paid_holidays_as_of (nullable) is None
        # and model_fields_set contains the field
        if self.qualified_for_paid_holidays_as_of is None and "qualified_for_paid_holidays_as_of" in self.model_fields_set:
            _dict['qualifiedForPaidHolidaysAsOf'] = None

        # set to None if default_job_pay_override (nullable) is None
        # and model_fields_set contains the field
        if self.default_job_pay_override is None and "default_job_pay_override" in self.model_fields_set:
            _dict['defaultJobPayOverride'] = None

        # set to None if code (nullable) is None
        # and model_fields_set contains the field
        if self.code is None and "code" in self.model_fields_set:
            _dict['code'] = None

        # set to None if schedules (nullable) is None
        # and model_fields_set contains the field
        if self.schedules is None and "schedules" in self.model_fields_set:
            _dict['schedules'] = None

        # set to None if allowed_location_ids (nullable) is None
        # and model_fields_set contains the field
        if self.allowed_location_ids is None and "allowed_location_ids" in self.model_fields_set:
            _dict['allowedLocationIds'] = None

        # set to None if other_jobs (nullable) is None
        # and model_fields_set contains the field
        if self.other_jobs is None and "other_jobs" in self.model_fields_set:
            _dict['otherJobs'] = None

        # set to None if fallback_supervisors (nullable) is None
        # and model_fields_set contains the field
        if self.fallback_supervisors is None and "fallback_supervisors" in self.model_fields_set:
            _dict['fallbackSupervisors'] = None

        # set to None if accounting_code_allocations (nullable) is None
        # and model_fields_set contains the field
        if self.accounting_code_allocations is None and "accounting_code_allocations" in self.model_fields_set:
            _dict['accountingCodeAllocations'] = None

        # set to None if external_id (nullable) is None
        # and model_fields_set contains the field
        if self.external_id is None and "external_id" in self.model_fields_set:
            _dict['externalId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of PositionRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "positionScheduleModeId": obj.get("positionScheduleModeId"),
            "contract": Int32LocatorRequest.from_dict(obj.get("contract")) if obj.get("contract") is not None else None,
            "positionType": Int32LocatorRequest.from_dict(obj.get("positionType")) if obj.get("positionType") is not None else None,
            "hoursPerFullWorkDay": obj.get("hoursPerFullWorkDay"),
            "needsReplacement": obj.get("needsReplacement"),
            "startDate": obj.get("startDate"),
            "endDate": obj.get("endDate"),
            "isStaffAugmentation": obj.get("isStaffAugmentation"),
            "fte": obj.get("fte"),
            "qualifiedForPto": obj.get("qualifiedForPto"),
            "qualifiedForPaidHolidays": obj.get("qualifiedForPaidHolidays"),
            "qualifiedForPtoAsOf": obj.get("qualifiedForPtoAsOf"),
            "qualifiedForPaidHolidaysAsOf": obj.get("qualifiedForPaidHolidaysAsOf"),
            "defaultJobPayOverride": obj.get("defaultJobPayOverride"),
            "code": obj.get("code"),
            "schedules": [PositionScheduleRequest.from_dict(_item) for _item in obj.get("schedules")] if obj.get("schedules") is not None else None,
            "replaceExistingPositionJobs": obj.get("replaceExistingPositionJobs"),
            "allowedLocationIds": [Int32LocatorRequest.from_dict(_item) for _item in obj.get("allowedLocationIds")] if obj.get("allowedLocationIds") is not None else None,
            "otherJobs": [PositionJobRequest.from_dict(_item) for _item in obj.get("otherJobs")] if obj.get("otherJobs") is not None else None,
            "primaryJob": PositionJobRequest.from_dict(obj.get("primaryJob")) if obj.get("primaryJob") is not None else None,
            "supervisor": Int32LocatorRequest.from_dict(obj.get("supervisor")) if obj.get("supervisor") is not None else None,
            "fallbackSupervisors": [Int32LocatorRequest.from_dict(_item) for _item in obj.get("fallbackSupervisors")] if obj.get("fallbackSupervisors") is not None else None,
            "accountingCodeAllocations": [AccountingCodeAllocationRequest.from_dict(_item) for _item in obj.get("accountingCodeAllocations")] if obj.get("accountingCodeAllocations") is not None else None,
            "id": obj.get("id"),
            "externalId": obj.get("externalId")
        })
        return _obj


