# coding: utf-8

"""
    Red Rover API

    Access Red Rover data via this REST API for Organizations that have granted you access.    # Authentication  The API is protected by HTTP Basic Authentication.   Each application that connects to the API has a unique username and password that it must supply with every request.    This value needs to be supplied as an HTTP Header: `Authorization=BASIC [hash]`. The value of [hash] is the string username:password base64 encoded.    Endpoints marked for Basic Auth can be used with the Basic Auth username and password that you have been assigned.    # API Information  ## Api Key  Each Red Rover organization that has authorized your application has a unique API Key for your application.  To retrieve the API Key, you can use the Organization endpoint (`api/v1/organization`) which returns an ApiKey uniquely used for each Organization.    You must supply this as an HTTP Header when accessing that organization: `apiKey=[apiKey]`. The domains that require this `ApiKey` header are labeled as 'Requires an ApiKey'.    ## Identifier  Where an `Identifier` can be specified in the route, you may either supply the Red Rover Id of the object (numeric) or the External Id (alpha-numeric). When specifying an External Id, you will need to prepend the External Id with the pipe character`|` (e.g. `|ABC123`). Please note that this is only the case when the External Id is within the route. If the External Id is contained within the body of the request, do not append the pipe character.    ## Rate Limiting  Requests are rate limited at a default rate of 100 requests per minute    ## Transaction Id  Each request can be supplied with a `TransactionId` GUID which will be logged with the request. The `Transaction Id` can be supplied as an HTTP Header: `TransactionId=[transactionId]`. If no `Transaction Id` is supplied, one will be generated for you. Please use a distinct TransactionId for each request.

    The version of the OpenAPI document: v1
    Contact: dev@redroverk12.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictInt
from pydantic import Field
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class TimeSettingsResponse(BaseModel):
    """
    TimeSettingsResponse
    """ # noqa: E501
    id: Optional[StrictInt] = Field(default=None, description="The unique identifier for the time settings object.")
    time_tracking_source_types: Optional[List[StrictInt]] = Field(default=None, description="The source from which time tracking data is obtained. It could be from a kiosk clock, an application clock, or manual entry. It can also be a combination of these sources.", alias="timeTrackingSourceTypes")
    time_tracking_mode: Optional[StrictInt] = Field(default=None, alias="timeTrackingMode")
    warn_if_manual_time_entry: Optional[StrictBool] = Field(default=None, description="A flag that triggers a warning if time entries are manually entered.", alias="warnIfManualTimeEntry")
    allow_time_durations_only: Optional[StrictBool] = Field(default=None, description="A flag that allows only time durations to be entered.", alias="allowTimeDurationsOnly")
    allow_break_time_durations_only: Optional[StrictBool] = Field(default=None, description="A flag that allows only break time durations to be entered.", alias="allowBreakTimeDurationsOnly")
    allow_multiple_breaks: Optional[StrictBool] = Field(default=None, description="A flag that allows multiple breaks to be entered.", alias="allowMultipleBreaks")
    hide_breaks_on_clock: Optional[StrictBool] = Field(default=None, description="A flag that hides breaks on the clock.", alias="hideBreaksOnClock")
    ignore_ip_restrictions: Optional[StrictBool] = Field(default=None, description="A flag that ignores IP restrictions.", alias="ignoreIPRestrictions")
    __properties: ClassVar[List[str]] = ["id", "timeTrackingSourceTypes", "timeTrackingMode", "warnIfManualTimeEntry", "allowTimeDurationsOnly", "allowBreakTimeDurationsOnly", "allowMultipleBreaks", "hideBreaksOnClock", "ignoreIPRestrictions"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TimeSettingsResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # set to None if time_tracking_source_types (nullable) is None
        # and model_fields_set contains the field
        if self.time_tracking_source_types is None and "time_tracking_source_types" in self.model_fields_set:
            _dict['timeTrackingSourceTypes'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of TimeSettingsResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "timeTrackingSourceTypes": obj.get("timeTrackingSourceTypes"),
            "timeTrackingMode": obj.get("timeTrackingMode"),
            "warnIfManualTimeEntry": obj.get("warnIfManualTimeEntry"),
            "allowTimeDurationsOnly": obj.get("allowTimeDurationsOnly"),
            "allowBreakTimeDurationsOnly": obj.get("allowBreakTimeDurationsOnly"),
            "allowMultipleBreaks": obj.get("allowMultipleBreaks"),
            "hideBreaksOnClock": obj.get("hideBreaksOnClock"),
            "ignoreIPRestrictions": obj.get("ignoreIPRestrictions")
        })
        return _obj


