# coding: utf-8

"""
    Red Rover API

    Access Red Rover data via this REST API for Organizations that have granted you access.    # Authentication  The API is protected by HTTP Basic Authentication.   Each application that connects to the API has a unique username and password that it must supply with every request.    This value needs to be supplied as an HTTP Header: `Authorization=BASIC [hash]`. The value of [hash] is the string username:password base64 encoded.    Endpoints marked for Basic Auth can be used with the Basic Auth username and password that you have been assigned.    # API Information  ## Api Key  Each Red Rover organization that has authorized your application has a unique API Key for your application.  To retrieve the API Key, you can use the Organization endpoint (`api/v1/organization`) which returns an ApiKey uniquely used for each Organization.    You must supply this as an HTTP Header when accessing that organization: `apiKey=[apiKey]`. The domains that require this `ApiKey` header are labeled as 'Requires an ApiKey'.    ## Identifier  Where an `Identifier` can be specified in the route, you may either supply the Red Rover Id of the object (numeric) or the External Id (alpha-numeric). When specifying an External Id, you will need to prepend the External Id with the pipe character`|` (e.g. `|ABC123`). Please note that this is only the case when the External Id is within the route. If the External Id is contained within the body of the request, do not append the pipe character.    ## Rate Limiting  Requests are rate limited at a default rate of 100 requests per minute    ## Transaction Id  Each request can be supplied with a `TransactionId` GUID which will be logged with the request. The `Transaction Id` can be supplied as an HTTP Header: `TransactionId=[transactionId]`. If no `Transaction Id` is supplied, one will be generated for you. Please use a distinct TransactionId for each request.

    The version of the OpenAPI document: v1
    Contact: dev@redroverk12.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool
from pydantic import Field
from typing_extensions import Annotated
from redrover_api.models.int32_locator_request import Int32LocatorRequest
from redrover_api.models.vacancy_detail_create_request import VacancyDetailCreateRequest
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class VacancyCreateRequest(BaseModel):
    """
    Vacancy Create Request
    """ # noqa: E501
    position_type: Optional[Int32LocatorRequest] = Field(default=None, alias="positionType")
    contract: Optional[Int32LocatorRequest] = None
    details: Optional[List[VacancyDetailCreateRequest]] = Field(default=None, description="The Details of the Vacancy")
    location: Optional[Int32LocatorRequest] = None
    bell_schedule: Optional[Int32LocatorRequest] = Field(default=None, alias="bellSchedule")
    title: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The Title of the Position that will be created")
    notes_to_replacement: Optional[Annotated[str, Field(strict=True, max_length=1500)]] = Field(default=None, description="Notes for the Replacement Substitute", alias="notesToReplacement")
    allow_sub_to_accept_part: Optional[StrictBool] = Field(default=None, description="Allows the Sub to accept individual parts of a Vacancy", alias="allowSubToAcceptPart")
    external_id: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="The External Id of the Vacancy", alias="externalId")
    pay_code: Optional[Int32LocatorRequest] = Field(default=None, alias="payCode")
    hold_for_manual_fill: Optional[StrictBool] = Field(default=None, description="This will hold the Vacancy until it will be manually filled", alias="holdForManualFill")
    administrator_comments: Optional[Annotated[str, Field(strict=True, max_length=1500)]] = Field(default=None, description="Administrator comments", alias="administratorComments")
    __properties: ClassVar[List[str]] = ["positionType", "contract", "details", "location", "bellSchedule", "title", "notesToReplacement", "allowSubToAcceptPart", "externalId", "payCode", "holdForManualFill", "administratorComments"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of VacancyCreateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of position_type
        if self.position_type:
            _dict['positionType'] = self.position_type.to_dict()
        # override the default output from pydantic by calling `to_dict()` of contract
        if self.contract:
            _dict['contract'] = self.contract.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in details (list)
        _items = []
        if self.details:
            for _item in self.details:
                if _item:
                    _items.append(_item.to_dict())
            _dict['details'] = _items
        # override the default output from pydantic by calling `to_dict()` of location
        if self.location:
            _dict['location'] = self.location.to_dict()
        # override the default output from pydantic by calling `to_dict()` of bell_schedule
        if self.bell_schedule:
            _dict['bellSchedule'] = self.bell_schedule.to_dict()
        # override the default output from pydantic by calling `to_dict()` of pay_code
        if self.pay_code:
            _dict['payCode'] = self.pay_code.to_dict()
        # set to None if notes_to_replacement (nullable) is None
        # and model_fields_set contains the field
        if self.notes_to_replacement is None and "notes_to_replacement" in self.model_fields_set:
            _dict['notesToReplacement'] = None

        # set to None if allow_sub_to_accept_part (nullable) is None
        # and model_fields_set contains the field
        if self.allow_sub_to_accept_part is None and "allow_sub_to_accept_part" in self.model_fields_set:
            _dict['allowSubToAcceptPart'] = None

        # set to None if external_id (nullable) is None
        # and model_fields_set contains the field
        if self.external_id is None and "external_id" in self.model_fields_set:
            _dict['externalId'] = None

        # set to None if administrator_comments (nullable) is None
        # and model_fields_set contains the field
        if self.administrator_comments is None and "administrator_comments" in self.model_fields_set:
            _dict['administratorComments'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of VacancyCreateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "positionType": Int32LocatorRequest.from_dict(obj.get("positionType")) if obj.get("positionType") is not None else None,
            "contract": Int32LocatorRequest.from_dict(obj.get("contract")) if obj.get("contract") is not None else None,
            "details": [VacancyDetailCreateRequest.from_dict(_item) for _item in obj.get("details")] if obj.get("details") is not None else None,
            "location": Int32LocatorRequest.from_dict(obj.get("location")) if obj.get("location") is not None else None,
            "bellSchedule": Int32LocatorRequest.from_dict(obj.get("bellSchedule")) if obj.get("bellSchedule") is not None else None,
            "title": obj.get("title"),
            "notesToReplacement": obj.get("notesToReplacement"),
            "allowSubToAcceptPart": obj.get("allowSubToAcceptPart"),
            "externalId": obj.get("externalId"),
            "payCode": Int32LocatorRequest.from_dict(obj.get("payCode")) if obj.get("payCode") is not None else None,
            "holdForManualFill": obj.get("holdForManualFill"),
            "administratorComments": obj.get("administratorComments")
        })
        return _obj


