# coding: utf-8

"""
    Red Rover API

    Access Red Rover data via this REST API for Organizations that have granted you access.    # Authentication  The API is protected by HTTP Basic Authentication.   Each application that connects to the API has a unique username and password that it must supply with every request.    This value needs to be supplied as an HTTP Header: `Authorization=BASIC [hash]`. The value of [hash] is the string username:password base64 encoded.    Endpoints marked for Basic Auth can be used with the Basic Auth username and password that you have been assigned.    # API Information  ## Api Key  Each Red Rover organization that has authorized your application has a unique API Key for your application.  To retrieve the API Key, you can use the Organization endpoint (`api/v1/organization`) which returns an ApiKey uniquely used for each Organization.    You must supply this as an HTTP Header when accessing that organization: `apiKey=[apiKey]`. The domains that require this `ApiKey` header are labeled as 'Requires an ApiKey'.    ## Identifier  Where an `Identifier` can be specified in the route, you may either supply the Red Rover Id of the object (numeric) or the External Id (alpha-numeric). When specifying an External Id, you will need to prepend the External Id with the pipe character`|` (e.g. `|ABC123`). Please note that this is only the case when the External Id is within the route. If the External Id is contained within the body of the request, do not append the pipe character.    ## Rate Limiting  Requests are rate limited at a default rate of 100 requests per minute    ## Transaction Id  Each request can be supplied with a `TransactionId` GUID which will be logged with the request. The `Transaction Id` can be supplied as an HTTP Header: `TransactionId=[transactionId]`. If no `Transaction Id` is supplied, one will be generated for you. Please use a distinct TransactionId for each request.

    The version of the OpenAPI document: v1
    Contact: dev@redroverk12.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictStr
from pydantic import Field
from typing_extensions import Annotated
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class WebhookResponse(BaseModel):
    """
    WebhookResponse
    """ # noqa: E501
    webhook_uri: Optional[StrictStr] = Field(default=None, description="The absolute uri that data will be posted to", alias="webhookUri")
    id: Optional[StrictStr] = Field(default=None, description="The Id of the Webhook (Guid)")
    version: Optional[StrictStr] = Field(default=None, description="The version of the webhook")
    created: Optional[datetime] = Field(default=None, description="When the webhook was created")
    updated: Optional[datetime] = Field(default=None, description="When the webhook was last updated")
    topic: Optional[StrictStr] = Field(default=None, description="Webhook topics are structure like such `DOMAIN/ACTION`.   Supported domains are `absence`, `vacancy`, `substitute_assignment`.  Supported actions are `create`, `update`, `delete`.")
    basic_auth_username: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="The Basic Auth username for the Basic Auth header that will be included in the Webhook payload", alias="basicAuthUsername")
    basic_auth_password: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="The Basic Auth password for the Basic Auth header that will be included in the Webhook payload", alias="basicAuthPassword")
    is_active: Optional[StrictBool] = Field(default=None, description="If the Webhook is active", alias="isActive")
    __properties: ClassVar[List[str]] = ["webhookUri", "id", "version", "created", "updated", "topic", "basicAuthUsername", "basicAuthPassword", "isActive"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of WebhookResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # set to None if webhook_uri (nullable) is None
        # and model_fields_set contains the field
        if self.webhook_uri is None and "webhook_uri" in self.model_fields_set:
            _dict['webhookUri'] = None

        # set to None if version (nullable) is None
        # and model_fields_set contains the field
        if self.version is None and "version" in self.model_fields_set:
            _dict['version'] = None

        # set to None if topic (nullable) is None
        # and model_fields_set contains the field
        if self.topic is None and "topic" in self.model_fields_set:
            _dict['topic'] = None

        # set to None if basic_auth_username (nullable) is None
        # and model_fields_set contains the field
        if self.basic_auth_username is None and "basic_auth_username" in self.model_fields_set:
            _dict['basicAuthUsername'] = None

        # set to None if basic_auth_password (nullable) is None
        # and model_fields_set contains the field
        if self.basic_auth_password is None and "basic_auth_password" in self.model_fields_set:
            _dict['basicAuthPassword'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of WebhookResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "webhookUri": obj.get("webhookUri"),
            "id": obj.get("id"),
            "version": obj.get("version"),
            "created": obj.get("created"),
            "updated": obj.get("updated"),
            "topic": obj.get("topic"),
            "basicAuthUsername": obj.get("basicAuthUsername"),
            "basicAuthPassword": obj.get("basicAuthPassword"),
            "isActive": obj.get("isActive")
        })
        return _obj


